# -*- coding: utf-8 -*-

# build all projects included in 'sample_src' folder.
# outputs goes sample_built except doc_ja and doc_en.
#
# Only tested on my environment, MS Windows 8.1 64bit with python3.
# The logged file may be unreadable, but works may be fine even that case.

import subprocess
import os
import sys
import shutil
import re

SPHINXBUILDPATH = r'C:\3bin\python32\Scripts\sphinx-build.exe'

def build_html(srcdir, dstdir, log, opts = ''):  
    p = subprocess.Popen(SPHINXBUILDPATH+' -b html '+srcdir+' '+dstdir,
                         stdout = log,
                         stderr = subprocess.STDOUT)
    p.wait()
    return p.returncode

def call_build_html(in_parent_dir, out_parent_dir, log):
    folders = os.listdir(in_parent_dir)
    for folder in folders:
        srcdir = os.path.join(in_parent_dir, folder)
        if not os.path.isdir(srcdir):
            continue
        srcdir = os.path.join(in_parent_dir, folder)
        dstdir = os.path.join(out_parent_dir, folder)
        if folder in ("doc_en", "doc_ja"):
            dstdir = os.path.join(out_parent_dir, "..", folder)
            dstdir = os.path.normpath(dstdir)
        print('from: ' + srcdir)
        print('to  : ' + dstdir)
        print("----" + folder + "----", file=log, flush=True)
        returncode = build_html(srcdir, dstdir, log)
        print ('return code = ', returncode)    

start_dir = os.path.dirname(sys.argv[0])
print('start at: ' + start_dir)
os.chdir(start_dir)
in_parent_dir = os.path.join(start_dir, 'sample_src')
out_parent_dir = os.path.join(start_dir, 'sample_built')
if not os.path.isdir(out_parent_dir):
    os.mkdir(out_parent_dir)
logpath = os.path.abspath('sphinx.log')
print('log: ' + logpath)
with open(logpath, 'wt', encoding="mbcs", errors="replace") as log:
    call_build_html(in_parent_dir, out_parent_dir, log)

# open the log
subprocess.Popen(logpath, shell = True, close_fds = True)
print ("finished.")
sys.exit()
